@@ -17,7 +17,7 @@ l=length(output.ratio$Common)
 design = designMatrix(lists)
 rowdes=nrow(design)-1
 row.names(design)<-seq(1,dim(design)[1])
-threshold = output.ratio$q
+threshold = output.ratio$h
 O = matrix(0,l,(rowdes))
 
 for(i in 1:l){
@@ -79,19 +79,19 @@ y1<-seq(1:l)
 y1<-matrix(y1,l,2)
 if(length(quantile[round(quantile[,1],3)>1,2])>0){
 Rmax = max(quantile[round(quantile[,1],3)>1,2])
-qmax = output.ratio$q[quantile[,2]==Rmax]
+hmax = output.ratio$h[quantile[,2]==Rmax]
 }
 if(length(quantile[round(quantile[,1],3)>1,2])==0){
 Rmax=1
 }
 
-main=paste("Distribution of Rq with ",as.character(conf),"% credibility interval")
+main=paste("Distribution of R(h) with ",as.character(conf),"% credibility interval")
 
-ps.options(horizontal=FALSE)
-setwd(dir)
-postscript("Rq.ps")
-plot(y1,lim1,xlab="P value",ylab="R",main=main,pch="_",axes=TRUE,yaxt="n",xaxt="n",
+########
+par(omd=c(0.1,0.9,0,1))
+plot(y1,lim1,xlab="P value",ylab="R",main=main,cex.main=0.7,pch="_",axes=TRUE,yaxt="n",xaxt="n",
 ylim=c(0,(max(quantile[1:l,3],na.rm=TRUE)+1*sd(quantile[1:l,3],na.rm=TRUE))),lwd=0.2)
+mtext("number of common genes",side=4,line=2,adj=0.5)
 
 if(Rmax==1){
 for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
@@ -101,52 +101,116 @@ cat("WARNING: the requested contrast is under-represented in the data (Rmax<1)\n
 }
 
 if(Rmax>1){
-    if(length(output.ratio$q[quantile[round(quantile[,1],3)>1,2]>=2])>0){
-        q2 = max(output.ratio$q[quantile[,2]>=2])
-        R2 = quantile[output.ratio$q==q2,2]
-if(q2==qmax){
+    if(length(output.ratio$h[quantile[round(quantile[,1],3)>1,2]>=2])>0){
+        h2 = max(output.ratio$h[quantile[,2]>=2])
+        R2 = quantile[output.ratio$h==h2,2]
+if(h2==hmax){
         for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
         axis(2, at = c(0,0.5,1,1.5,Rmax), labels = c(0,0.5,1,1.5,expression(R[max])), tick = TRUE,cex.axis=0.9)
         if(output.ratio$pvalue==TRUE){   
-        axis(1, at = c((qmax*100),seq(((qmax*100)+10),100,20)), labels = c(expression(q[max]),seq((qmax+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+        axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),seq((hmax+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
         }
                 if(output.ratio$pvalue==FALSE){   
-                axis(1, at = c((qmax*100),seq(((qmax*100)+10),100,20)), labels = c(expression(q[max]),1-seq((q2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+                axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),1-seq((h2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
                 }
-                axis(4, at = c(1,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$q==qmax]),tick=TRUE,cex=0.9)
+                axis(4, at = c(1,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$h==hmax]),tick=TRUE,cex=0.9)
 }
-if(q2!=qmax){
+if(h2!=hmax){
         for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
         axis(2, at = c(0,0.5,1,1.5,R2,Rmax), labels = c(0,0.5,1,1.5,expression(R[2]),expression(R[max])), tick = TRUE,cex.axis=0.9)
         if(output.ratio$pvalue==TRUE){   
-        axis(1, at = c((qmax*100),(q2*100),seq(((q2*100)+10),100,20)), labels = c(expression(q[max]),expression(q[2]),seq((q2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+        axis(1, at = c((hmax*100),(h2*100),seq(((h2*100)+10),100,20)), labels = c(expression(h[max]),expression(h[2]),seq((h2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
         }
                 if(output.ratio$pvalue==FALSE){   
-                axis(1, at = c((qmax*100),(q2*100),seq(((q2*100)+10),100,20)), labels = c(expression(q[max]),expression(q[2]),1-seq((q2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+                axis(1, at = c((hmax*100),(h2*100),seq(((h2*100)+10),100,20)), labels = c(expression(h[max]),expression(h[2]),1-seq((h2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
                 }
-                axis(4, at = c(1,R2,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$q==q2],output.ratio$Common[output.ratio$q==qmax]),tick=TRUE,cex=0.9)
+                axis(4, at = c(1,R2,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$h==h2],output.ratio$Common[output.ratio$h==hmax]),tick=TRUE,cex=0.9)
         }
 abline(h=R2,lty=3,cex=0.7)
 }
-    if(length(output.ratio$q[quantile[round(quantile[,1],3)>1,2]>=2])==0){
+    if(length(output.ratio$h[quantile[round(quantile[,1],3)>1,2]>=2])==0){
 
         for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
         axis(2, at = c(seq(0,(Rmax-0.5),0.5),Rmax), labels = c(seq(0,(Rmax-0.5),0.5),expression(R[max])), tick = TRUE,cex.axis=0.9)
         if(output.ratio$pvalue==TRUE){   
-        axis(1, at = c((qmax*100),seq(((qmax*100)+10),100,20)), labels = c(expression(q[max]),seq((qmax+0.1),1,0.2)), tick=TRUE,cex=0.9,las=2)
+        axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),seq((hmax+0.1),1,0.2)), tick=TRUE,cex=0.9,las=2)
         }
                 if(output.ratio$pvalue==FALSE){   
-                axis(1, at = c((qmax*100),seq(((qmax*100)+10),100,20)), labels = c(expression(q[max]),1-seq((qmax+0.1),1,0.2)), tick=TRUE,cex=0.9,las=2)
+                axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),1-seq((hmax+0.1),1,0.2)), tick=TRUE,cex=0.9,las=2)
                 }
         }
 
-axis(4, at = c(1,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$q==qmax]),tick=TRUE,cex=0.9)
+axis(4, at = c(1,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$h==hmax]),tick=TRUE,cex=0.9)
+}
+abline(h=1,col="black", lwd=1.5)
+points(y1[,1],quantile[1:l,2],col="red",cex=0.5)
+abline(h=Rmax,lty=3,cex=0.7)
+########
+
+ps.options(horizontal=FALSE)
+setwd(dir)
+postscript("Rh.ps")
+par(omd=c(0.1,0.9,0,1))
+plot(y1,lim1,xlab="P value",ylab="R",main=main,cex.main=0.7,pch="_",axes=TRUE,yaxt="n",xaxt="n",
+ylim=c(0,(max(quantile[1:l,3],na.rm=TRUE)+1*sd(quantile[1:l,3],na.rm=TRUE))),lwd=0.2)
+mtext("number of common genes",side=4,line=2,adj=0.5)
+
+if(Rmax==1){
+for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
+        axis(2, at = c(0,0.5,1,1.5), labels = c(0,0.5,1,1.5), tick = TRUE,cex.axis=0.9)
+axis(1, at = seq(1:l), labels = seq(1:l),tick=TRUE,cex=0.9,las=2)
+cat("WARNING: the requested contrast is under-represented in the data (Rmax<1)\n")
+}
+
+if(Rmax>1){
+    if(length(output.ratio$h[quantile[round(quantile[,1],3)>1,2]>=2])>0){
+        h2 = max(output.ratio$h[quantile[,2]>=2])
+        R2 = quantile[output.ratio$h==h2,2]
+if(h2==hmax){
+        for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
+        axis(2, at = c(0,0.5,1,1.5,Rmax), labels = c(0,0.5,1,1.5,expression(R[max])), tick = TRUE,cex.axis=0.9)
+        if(output.ratio$pvalue==TRUE){   
+        axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),seq((hmax+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+        }
+                if(output.ratio$pvalue==FALSE){   
+                axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),1-seq((h2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+                }
+                axis(4, at = c(1,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$h==hmax]),tick=TRUE,cex=0.9)
+}
+if(h2!=hmax){
+        for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
+        axis(2, at = c(0,0.5,1,1.5,R2,Rmax), labels = c(0,0.5,1,1.5,expression(R[2]),expression(R[max])), tick = TRUE,cex.axis=0.9)
+        if(output.ratio$pvalue==TRUE){   
+        axis(1, at = c((hmax*100),(h2*100),seq(((h2*100)+10),100,20)), labels = c(expression(h[max]),expression(h[2]),seq((h2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+        }
+                if(output.ratio$pvalue==FALSE){   
+                axis(1, at = c((hmax*100),(h2*100),seq(((h2*100)+10),100,20)), labels = c(expression(h[max]),expression(h[2]),1-seq((h2+0.1),1,0.2)),tick=TRUE,cex=0.9,las=2)
+                }
+                axis(4, at = c(1,R2,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$h==h2],output.ratio$Common[output.ratio$h==hmax]),tick=TRUE,cex=0.9)
+        }
+abline(h=R2,lty=3,cex=0.7)
+}
+    if(length(output.ratio$h[quantile[round(quantile[,1],3)>1,2]>=2])==0){
+
+        for (i in 1:l) lines(y1[i,],lim1[i,], lty=3,lwd=1.7)
+        axis(2, at = c(seq(0,(Rmax-0.5),0.5),Rmax), labels = c(seq(0,(Rmax-0.5),0.5),expression(R[max])), tick = TRUE,cex.axis=0.9)
+        if(output.ratio$pvalue==TRUE){   
+        axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),seq((hmax+0.1),1,0.2)), tick=TRUE,cex=0.9,las=2)
+        }
+                if(output.ratio$pvalue==FALSE){   
+                axis(1, at = c((hmax*100),seq(((hmax*100)+10),100,20)), labels = c(expression(h[max]),1-seq((hmax+0.1),1,0.2)), tick=TRUE,cex=0.9,las=2)
+                }
+        }
+
+axis(4, at = c(1,Rmax),labels = c(dim1,output.ratio$Common[output.ratio$h==hmax]),tick=TRUE,cex=0.9)
 }
 abline(h=1,col="black", lwd=1.5)
 points(y1[,1],quantile[1:l,2],col="red",cex=0.5)
 abline(h=Rmax,lty=3,cex=0.7)
 dev.off()
 
+rownames(quantile)<-output.ratio$h
+
 return(quantile=quantile)
 }
 
